@@ -11,14 +11,6 @@ const CHOOSE_HELP: &str = "Select one or more recipes to run using a binary choo
                            If `--chooser` is not passed the chooser defaults to the \
                            value of $JUST_CHOOSER, falling back to `fzf`";
 
-pub(crate) fn chooser_default(justfile: &Path) -> OsString {
-  let mut chooser = OsString::new();
-  chooser.push("fzf --multi --preview 'just --unstable --color always --justfile \"");
-  chooser.push(justfile);
-  chooser.push("\" --show {}'");
-  chooser
-}
-
 #[derive(Debug, PartialEq)]
 pub(crate) struct Config {
   pub(crate) check: bool,
@@ -381,10 +373,9 @@ impl Config {
       .arg(
         Arg::new(cmd::COMPLETIONS)
           .long("completions")
-          .action(ArgAction::Append)
-          .num_args(1..)
+          .action(ArgAction::Set)
           .value_name("SHELL")
-          .value_parser(value_parser!(clap_complete::Shell))
+          .value_parser(value_parser!(completions::Shell))
           .ignore_case(true)
           .help("Print shell completion script for <SHELL>"),
       )
@@ -569,15 +560,20 @@ impl Config {
     }
   }
 
-  fn parse_module_path(path: ValuesRef<String>) -> ConfigResult<ModulePath> {
+  fn parse_module_path(values: ValuesRef<String>) -> ConfigResult<ModulePath> {
+    let path = values.clone().map(|s| (*s).as_str()).collect::<Vec<&str>>();
+
+    let path = if path.len() == 1 && path[0].contains(' ') {
+      path[0].split_whitespace().collect::<Vec<&str>>()
+    } else {
+      path
+    };
+
     path
-      .clone()
-      .map(|s| (*s).as_str())
-      .collect::<Vec<&str>>()
       .as_slice()
       .try_into()
       .map_err(|()| ConfigError::ModulePath {
-        path: path.cloned().collect(),
+        path: values.cloned().collect(),
       })
   }
 
@@ -686,7 +682,7 @@ impl Config {
         arguments,
         overrides,
       }
-    } else if let Some(&shell) = matches.get_one::<clap_complete::Shell>(cmd::COMPLETIONS) {
+    } else if let Some(&shell) = matches.get_one::<completions::Shell>(cmd::COMPLETIONS) {
       Subcommand::Completions { shell }
     } else if matches.get_flag(cmd::EDIT) {
       Subcommand::Edit
@@ -1255,13 +1251,13 @@ mod tests {
   test! {
     name: subcommand_completions,
     args: ["--completions", "bash"],
-    subcommand: Subcommand::Completions{ shell: clap_complete::Shell::Bash },
+    subcommand: Subcommand::Completions{ shell: completions::Shell::Bash },
   }
 
   test! {
     name: subcommand_completions_uppercase,
     args: ["--completions", "BASH"],
-    subcommand: Subcommand::Completions{ shell: clap_complete::Shell::Bash },
+    subcommand: Subcommand::Completions{ shell: completions::Shell::Bash },
   }
 
   error! {
@@ -1544,15 +1540,30 @@ mod tests {
   }
 
   error_matches! {
-    name: completions_arguments,
-    args: ["--completions", "zsh", "foo"],
+    name: completions_argument,
+    args: ["--completions", "foo"],
     error: error,
     check: {
       assert_eq!(error.kind(), clap::error::ErrorKind::InvalidValue);
       assert_eq!(error.context().collect::<Vec<_>>(), vec![
-        (ContextKind::InvalidArg, &ContextValue::String("--completions <SHELL>...".into())),
-        (ContextKind::InvalidValue, &ContextValue::String("foo".into())),
-        (ContextKind::ValidValue, &ContextValue::Strings(["bash".into(), "elvish".into(), "fish".into(), "powershell".into(), "zsh".into()].into())),
+        (
+          ContextKind::InvalidArg,
+          &ContextValue::String("--completions <SHELL>".into())),
+        (
+          ContextKind::InvalidValue,
+          &ContextValue::String("foo".into()),
+        ),
+        (
+          ContextKind::ValidValue,
+          &ContextValue::Strings([
+            "bash".into(),
+            "elvish".into(),
+            "fish".into(),
+            "nushell".into(),
+            "powershell".into(),
+            "zsh".into()].into()
+          ),
+        ),
       ]);
     },
   }
