@@ -340,6 +340,11 @@ impl<'run, 'src> Parser<'run, 'src> {
             self.presume_keyword(Keyword::Export)?;
             items.push(Item::Assignment(self.parse_assignment(true)?));
           }
+          Some(Keyword::Unexport) => {
+            self.presume_keyword(Keyword::Unexport)?;
+            let name = self.parse_name()?;
+            items.push(Item::Unexport { name });
+          }
           Some(Keyword::Import)
             if self.next_are(&[Identifier, StringToken])
               || self.next_are(&[Identifier, Identifier, StringToken])
@@ -982,15 +987,18 @@ impl<'run, 'src> Parser<'run, 'src> {
       loop {
         let name = self.parse_name()?;
 
-        let argument = if self.accepted(ParenL)? {
-          let argument = self.parse_string_literal()?;
+        let maybe_argument = if self.accepted(Colon)? {
+          let arg = self.parse_string_literal()?;
+          Some(arg)
+        } else if self.accepted(ParenL)? {
+          let arg = self.parse_string_literal()?;
           self.expect(ParenR)?;
-          Some(argument)
+          Some(arg)
         } else {
           None
         };
 
-        let attribute = Attribute::new(name, argument)?;
+        let attribute = Attribute::new(name, maybe_argument)?;
 
         if let Some(line) = attributes.get(&attribute) {
           return Err(name.error(CompileErrorKind::DuplicateAttribute {
@@ -1153,6 +1161,18 @@ mod tests {
     tree: (justfile (alias t test)),
   }
 
+  test! {
+    name: single_argument_attribute_shorthand,
+    text: "[group: 'some-group']\nalias t := test",
+    tree: (justfile (alias t test)),
+  }
+
+  test! {
+    name: single_argument_attribute_shorthand_multiple_same_line,
+    text: "[group: 'some-group', group: 'some-other-group']\nalias t := test",
+    tree: (justfile (alias t test)),
+  }
+
   test! {
     name: aliases_multiple,
     text: "alias t := test\nalias b := build",
