@@ -144,3 +144,26 @@ fn list_groups_with_custom_prefix() {
     )
     .run();
 }
+
+#[test]
+fn list_groups_with_shorthand_syntax() {
+  Test::new()
+    .justfile(
+      "
+        [group: 'B']
+        foo:
+
+        [group: 'A', group: 'B']
+        bar:
+      ",
+    )
+    .args(["--groups", "--list-prefix", "..."])
+    .stdout(
+      "
+      Recipe groups:
+      ...A
+      ...B
+      ",
+    )
+    .run();
+}
