@@ -104,7 +104,10 @@ mod summary;
 mod tempdir;
 mod timestamps;
 mod undefined_variables;
+mod unexport;
 mod unstable;
+#[cfg(windows)]
+mod windows;
 #[cfg(target_family = "windows")]
 mod windows_shell;
 mod working_directory;
